<?php $TRANSLATIONS = array(
"Music" => "Muzică",
"songs" => "melodii",
"albums" => "albume",
"Add album to playlist" => "Adaugă albumul la lista de redare",
"Play" => "Redă",
"Pause" => "Pauză",
"Previous" => "Precedent",
"Next" => "Următor",
"Mute" => "Fără sonor",
"Unmute" => "Cu sonor",
"Rescan Collection" => "Rescanează colecția",
"Artist" => "Artist",
"Album" => "Album",
"Title" => "Titlu"
);
